utils::globalVariables(
  c(
    "CNTR_ID",
    "database",
    "databasex",
    "Department",
    "code",
    "DOI",
    "extension",
    "id",
    "ifn",
    "ifnx",
    "ISO3_CODE",
    "lat",
    "layer",
    "layer_shrt",
    "Letter",
    "lon",
    "mfe50_provinces",
    "NAME",
    "NAME_ENGL",
    "Number",
    "province",
    "Species",
    "TABLE_NAME",
    "TABLE_TYPE",
    "url_field_db",
    "url_sig_db",
    "Version",
    "Year",
    "year",
    "."
  ))
